import unittest
import os
import modpipe.test
import modpipe.binaries
import subprocess
import modeller

class TMAlignTests(modpipe.test.TestCase):

    def test_tmalign(self):
        """Check TM-align"""
        seqs = ('GKSYPTVSPD', 'GKSYPTVSPS')
        fnames = ('test1.pdb', 'test2.pdb')
        e = modeller.Environ()
        e.libs.topology.read('${LIB}/top_heav.lib')
        e.libs.parameters.read('${LIB}/par.lib')

        chains = []
        for s, fname in zip(seqs, fnames):
            m = modeller.Model(e)
            m.build_sequence(s)
            m.write(file=fname)
            chains.append(m.chains[0].name)

        binary = modpipe.binaries.get_tmalign()
        p = subprocess.Popen([binary, '-p', fnames[0], '-q', fnames[1],
                              '-a', chains[0], '-b', chains[1]],
                             stdout=subprocess.PIPE,
                             universal_newlines=True)
        lines = p.stdout.readlines()
        self.require_clean_exit(p)
        p.stdout.close()
        self.assertEqual([line.rstrip('\r\n') for line in lines[-4:-1]],
                         ['Chain 1: ' + seqs[0], 'Eqvpos : ::::::::::',
                          'Chain 2: ' + seqs[1]])
        for f in fnames:
            os.unlink(f)

if __name__ == '__main__':
    unittest.main()
